Module node

Module node 

Node

Internal structures for representing nodes in a decision tree. This includes SplittableNode used during training and Node used for inference.

Structs

Node
NodeStats
Statistics stored for each node when save_node_stats is enabled.
SplittableNode

Enums

NodeType

Functions

deserialize_left_cats
serialize_left_cats