Node
Internal structures for representing nodes in a decision tree.
This includes SplittableNode used during training and Node used for inference.
Structs
- Node
- Node
Stats - Statistics stored for each node when save_node_stats is enabled.
- Splittable
Node